@@ -28,6 +28,7 @@ import urlparse
 import gobject
 import gtk
 from gtk import glade
+from pango import parse_markup
 import translate
 
 import rpc
@@ -445,7 +446,18 @@ class db_login(object):
                 if butconnect:
                     butconnect.set_sensitive(False)
             else:
-                label.hide()
+                lm = rpc.session.login_message(url)
+                if lm:
+                    try:
+                        parse_markup(lm)
+                    except:
+                        label.hide()
+                    else:
+                        label.set_label(lm)
+                        label.show()
+                else:
+                    label.hide()
+
                 db_widget.show()
                 if butconnect:
                     butconnect.set_sensitive(True)
@@ -1022,7 +1034,7 @@ class terp_main(service.Service):
                 elif log_response == RES_CNX_ERROR:
                     common.message(_('Connection error !\nUnable to connect to the server !'))
                 elif log_response == RES_BAD_PASSWORD:
-                    common.message(_('Connection error !\nBad username or password !'))
+                    common.message(_('Authentication error !\nBad Username or Password !'))
         except rpc.rpc_exception:
             rpc.session.logout()
             raise
@@ -1438,7 +1450,17 @@ class terp_main(service.Service):
                 db_widget.hide()
                 label.show()
             else:
-                label.hide()
+                lm = rpc.session.login_message(url)
+                if lm:
+                    try:
+                        parse_markup(lm)
+                    except:
+                        label.hide()
+                    else:
+                        label.set_label(lm)
+                        label.show()
+                else:
+                    label.hide()
                 db_widget.show()
             return res
 
