@@ -174,8 +174,18 @@ class Screen(signal_event.signal_event):
     def search_filter(self, *args):
         v = self.filter_widget.value
         filter_keys = [ key for key, _, _ in v]
-        v.extend((key, op, value) for key, op, value in self.domain if key not in filter_keys and not (key=='active' and self.context.get('active_test', False)))
-        if self.latest_search and self.latest_search != v:
+
+        for element in self.domain:
+            if not isinstance(element,tuple): # Filtering '|' symbol
+                v.append(element)
+            else:
+                (key, op, value) = element
+                if key not in filter_keys and not (key=='active' and self.context.get('active_test', False)):
+                    v.append((key, op, value))
+
+#        v.extend((key, op, value) for key, op, value in domain if key not in filter_keys and not (key=='active' and self.context.get('active_test', False)))
+
+        if self.latest_search != v:
             self.filter_widget.set_offset(0)
         limit=self.filter_widget.get_limit()
         offset=self.filter_widget.get_offset()
